@@ -8,13 +8,15 @@ use LWP::UserAgent;
 use JSON;
 use URI::Encode qw(uri_encode);
 
+$ENV{PERL_LWP_SSL_VERIFY_HOSTNAME} = 0;
 use IO::Socket::SSL;
 IO::Socket::SSL::set_ctx_defaults( 
      SSL_verifycn_scheme => 'www', 
      SSL_verify_mode => 0,
+     verify_mode => 0,
 );
 
-our $VERSION = '1.11.1';
+our $VERSION = '1.12.1';
 
 =head1 NAME
 
@@ -86,6 +88,7 @@ sub new {
 	$ua->env_proxy;
 	$ua->max_redirect(32); # for the simple API only
 	$ua->agent("WebService::Browshot $VERSION");
+	$ua->ssl_opts( verify_hostnames => 0 );
 
   	my $browshot = {	
 		_key	=> $args{key}	|| '',
@@ -366,7 +369,7 @@ Required. Screenshot ID.
 
 sub screenshot_info {
 	my ($self, %args) 	= @_;
-	my $id				= $args{id}	|| $self->error("Missing id in screenshot_info");
+	my $id			= $args{id}	|| $self->error("Missing id in screenshot_info");
 
 
 	return $self->return_reply(action => 'screenshot/info', parameters => { %args });
@@ -396,6 +399,31 @@ sub screenshot_list {
 	return $self->return_reply(action => 'screenshot/list', parameters => { %args });
 }
 
+=head2 screenshot_search()
+
+  $browshot->screenshot_search(url => 'google.com')
+
+Get details about screenshots requested. See L<http://browshot.com/api/documentation#screenshot_search> for the response format.
+
+Arguments:
+
+=over 4
+
+=item url
+
+Required. URL string to look for.
+
+=back
+
+=cut
+
+sub screenshot_search {
+	my ($self, %args) 	= @_;
+	my $url			= $args{url}	|| $self->error("Missing id in screenshot_search");
+
+	return $self->return_reply(action => 'screenshot/search', parameters => { %args });
+}
+
 =head2 screenshot_host()
 
   $browshot->screenshot_host(id => 12345, hosting => 'cdn')
@@ -707,13 +735,17 @@ sub generic_error {
 
 =over 4
 
+=item 1.12
+
+Add C<screenshot_search> for API 1.12.
+
 =item 1.11.1
 
 Return Browshot response in case of error if the reply is valid JSON.
 
 =item 1.11
 
-Compatible with API 1.11. Option HTTP timeout.
+Compatible with API 1.11. Optional HTTP timeout.
 
 =item 1.10
 
